from typing import List

from transformers import AutoModelForSeq2SeqLM, AutoTokenizer

MODEL_NAMES = ["sobamchan/bart-large-scitldr"]


class SchnitSum:
    def __init__(self, model_name: str = None, use_gpu=False):
        """Easy to use summarization package.
        model_name (str): Model name to use.
        use_gpu (bool): Whether use GPU for inference or not.
        """

        if model_name not in MODEL_NAMES:
            model_names_str = "\n".join([f"- {name}" for name in MODEL_NAMES])
            raise ValueError(
                f"{model_name} is not currently supported. Pick one from\n"
                f"{model_names_str}"
            )

        print(f"Initializing a {model_name} ...")

        self.tokenizer = AutoTokenizer.from_pretrained(model_name)
        model = AutoModelForSeq2SeqLM.from_pretrained(model_name)

        if use_gpu:
            model = model.to("cuda")

        self.use_gpu = use_gpu
        self.model = model
        self.model_name = model_name
        print("loaded!")

    def summarize_batch(self, texts: List[str]) -> List[str]:
        inputs = self.tokenizer(
            texts, padding="max_length", truncation=True, return_tensors="pt"
        )
        summary_ids = self.model.generate(
            inputs["input_ids"].to("cuda") if self.use_gpu else inputs["input_ids"],
            max_length=250,
            num_beams=1,
            early_stopping=True,
        )
        return self.tokenizer.batch_decode(summary_ids, skip_special_tokens=True)

    def __call__(self, texts: List[str]) -> List[str]:
        return self.summarize_batch(texts)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['schnitsum']

package_data = \
{'': ['*']}

install_requires = \
['torch>=1.12.1,<2.0.0', 'transformers>=4.22.2,<5.0.0']

setup_kwargs = {
    'name': 'schnitsum',
    'version': '0.1.1',
    'description': '',
    'long_description': '# Schnitsum: Easy to use neural network based summarization models\n\nThis package enables to generate summaries of you documents of interests.\n\nCurrently, we support following models,\n\n- [BART (large)](https://aclanthology.org/2020.acl-main.703) fine-tuned on computer science papers (ref. [SciTLDR](https://aclanthology.org/2020.findings-emnlp.428)).\n  - Model name: `sobamchan/bart-large-scitldr`\n\nwe are planning to expand coverage soon to other domains, languages, models soon.\n\n\n# Installation\n\n```bash\npip install schnitsum  # or poetry add schnitsum\n```\n\nThis will let you generate summaries with CPUs only, if you want to utilize your GPUs, please follow the instruction by PyTorch, [here](https://pytorch.org/get-started/locally/).\n\n\n# Usage\n\n```py3\nfrom schnitsum import SchnitSum\nmodel = SchnitSum("sobamchan/bart-large-scitldr")\n\ndocs = [\n    "Document you want to summarize."\n]\n\nsummaries = model(docs)\nprint(summaries)\n```\n',
    'author': 'sobamchan',
    'author_email': 'oh.sore.sore.soutarou@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
